AbstractSettingsTile class abstract

Abstract base class for settings tiles.

Platform-specific implementations (Android, iOS, Web) extend this class and implement the build method with platform-appropriate styling.

Note: IOSSettingsTile is a StatefulWidget (for press animation state) and does not extend this class, but maintains the same constructor signature.

Inheritance
Implementers

Constructors

AbstractSettingsTile({required Widget? title, required SettingsTileType tileType, Widget? leading, Widget? trailing, Widget? description, Widget? value, void onPressed(BuildContext context)?, void onToggle(bool value)?, bool? initialValue, Color? activeSwitchColor, bool enabled = true, String? inputValue, void onInputChanged(String)?, String? inputHint, TextInputType? inputKeyboardType, int? inputMaxLength, double? sliderValue, void onSliderChanged(double)?, double sliderMin = 0, double sliderMax = 1, int? sliderDivisions, List<SettingsOption>? selectOptions, String? selectValue, void onSelectChanged(String?)?, String? textareaValue, void onTextareaChanged(String)?, String? textareaHint, int textareaMaxLines = 3, int? textareaMaxLength, List<SettingsOption>? radioOptions, String? radioValue, void onRadioChanged(String?)?, List<SettingsOption>? checkboxOptions, Set<String>? checkboxValues, void onCheckboxChanged(Set<String>)?, Key? key})
const

Properties

activeSwitchColor Color?
Color for the active state of switch tiles.
final
checkboxOptions List<SettingsOption>?
Available options for checkbox group tile.
final
checkboxValues Set<String>?
Currently selected values for checkbox group tile.
final
description Widget?
The widget at the bottom of the title.
final
enabled bool
Whether the tile is enabled for interaction.
final
hashCode int
The hash code for this object.
no setterinherited
initialValue bool?
Initial value for switch tiles.
final
inputHint String?
Placeholder text for input tile.
final
inputKeyboardType TextInputType?
Keyboard type for input tile.
final
inputMaxLength int?
Maximum character length for input tile.
final
inputValue String?
Current text value for input tile.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leading Widget?
The widget at the beginning of the tile.
final
onCheckboxChanged → void Function(Set<String>)?
Callback when checkbox selection changes.
final
onInputChanged → void Function(String)?
Callback when input text changes.
final
onPressed → void Function(BuildContext context)?
Callback when the tile is pressed.
final
onRadioChanged → void Function(String?)?
Callback when radio selection changes.
final
onSelectChanged → void Function(String?)?
Callback when selection changes.
final
onSliderChanged → void Function(double)?
Callback when slider value changes.
final
onTextareaChanged → void Function(String)?
Callback when textarea text changes.
final
onToggle → void Function(bool value)?
Callback when the switch is toggled (for switch tiles).
final
radioOptions List<SettingsOption>?
Available options for radio group tile.
final
radioValue String?
Currently selected value for radio group tile.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectOptions List<SettingsOption>?
Available options for select tile.
final
selectValue String?
Currently selected value for select tile.
final
sliderDivisions int?
Number of discrete divisions for slider tile.
final
sliderMax double
Maximum value for slider tile.
final
sliderMin double
Minimum value for slider tile.
final
sliderValue double?
Current value for slider tile.
final
textareaHint String?
Placeholder text for textarea tile.
final
textareaMaxLength int?
Maximum character length for textarea tile.
final
textareaMaxLines int
Number of visible lines for textarea tile.
final
textareaValue String?
Current text value for textarea tile.
final
tileType SettingsTileType
The type of this tile (simple, switch, navigation, or check).
final
title Widget?
The main title widget of the tile.
final
trailing Widget?
The widget at the end of the tile.
final
value Widget?
The value widget displayed below or next to the title.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
inherited
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited